@@ -1,6 +1,7 @@
 """
 Utilities to read content of a single file.
 """
+
 import os
 from contextlib import contextmanager
 from pathlib import Path
@@ -70,9 +71,9 @@ def yield_chunked_bytes(file_or_io: PathOrIO, chunk_size=1024 * 1024) -> Iterabl
     Returns:
         bytes content
     """
-    with open_file_or_io(file_or_io, mode="rb") as fh:
+    with open_file_or_io(file_or_io, mode="rb") as fh:  # noqa, pylint: disable=W0135
         while True:
-            data = fh.read(chunk_size)
+            data = fh.read(chunk_size)  # noqa
             if len(data) == 0:
                 break
             yield data
@@ -122,5 +123,18 @@ def yield_lines_from_file(
     Returns:
         Generator of stripped lines
     """
-    content = Path(file).read_text(encoding=encoding)
-    yield from yield_lines_from_object(content, strip=strip, skip_empty=skip_empty)
+    with Path(file).open(encoding=encoding) as fh:
+        while True:
+            next_line = fh.readline()
+            if len(next_line) == 0:
+                # empty lines will have at least a newline character
+                # so this is only true if EOF is reached.
+                break
+            if strip:
+                next_line = next_line.strip()
+            if skip_empty:
+                if strip and next_line == "":
+                    continue
+                if not strip and next_line.strip("\r\n") == "":
+                    continue
+            yield next_line
