@@ -2,14 +2,19 @@
 Wrapper functions for json files.
 
 Behaviour of the JSON writer is changed to:
-    - Automatically converts JSON incompatible data types to lists
-    (pathlib.Path, numpy arrays, torch tensors, jax tensors) instead of raising errors
+    - Automatically converts JSON incompatible data types
+    (pathlib.Path, numpy arrays, torch tensors, jax tensors) instead of raising errors.
+    Paths become strings, tensors become lists.
     - Does not indent each list element as a new line
 
 Possible improvements:
     - Refactor the "file_or_io" handling into a context manager
 
 """
+
+import math
+import sys
+
 import io
 import json
 import os
@@ -48,19 +53,9 @@ def load_json(file_or_io: PathOrIO, verbose: bool = False, encoding: str = "utf-
     try:
         obj = loads_json(data_str)
     except Exception as e:
-        # # todo use a general way to reraise the same exception with added information.
-        # print(f"{e=} {e.args=}")
-        # if len(e.args) > 0:
-        #     _msg = e.args[0]
-        #     remaining_args = e.args[1:]
-        # else:
-        #     remaining_args = tuple()
-        # print(f"{remaining_args=} {type(e)=}")
-        # raise type(e)(
-        #     f"Error loading json file {file_or_io} due to {format_exception(e)}", *remaining_args
-        # ) from e
+        # # TODO use a general way to reraise the same exception with added information.
         raise RuntimeError(
-            f"Error loading json file {file_or_io} due to {format_exception(e)}"
+            f"Probably corrupt json file {file_or_io}",
         ) from e
 
     if verbose:
@@ -142,19 +137,6 @@ def _check_can_write(file_or_io, overwrite, verbose):
     return True
 
 
-def dump_json_safely(obj: Any, f: PathType, **kwargs):
-    try:
-        dump_json(obj, f, **kwargs)
-    except KeyboardInterrupt as e:
-        print(f"Deleting {f} due to KeyboardInterrupt")
-        try:
-            os.remove(f)
-        except Exception as e2:
-            print(f"Exception while deleting {f}: {format_exception(e2)}")
-            pass
-        raise e
-
-
 def dump_json(
     obj: Any,
     file_or_io: PathOrIO,
@@ -163,11 +145,14 @@ def dump_json(
     allow_nan=False,
     indent=None,
     separators=None,
+    default=None,
     sort_keys=False,
     verbose: bool = True,
     create_parent=False,
     float_precision=None,
     custom_format=True,
+    custom_format_nan_to_none=False,
+    custom_format_indent_lists=False,
     encoding="utf-8",
     overwrite=True,
 ) -> None:
@@ -188,6 +173,7 @@ def dump_json(
             allow_nan=allow_nan,
             indent=indent,
             separators=separators,
+            default=default,
             sort_keys=sort_keys,
         )
         if custom_format:
@@ -195,6 +181,8 @@ def dump_json(
                 dict(
                     cls=CustomJSONEncoder,
                     float_precision=float_precision,
+                    custom_format_nan_to_none=custom_format_nan_to_none,
+                    custom_format_indent_lists=custom_format_indent_lists,
                 )
             )
         try:
@@ -218,11 +206,14 @@ def dump_json_compressed(
     allow_nan=False,
     indent=None,
     separators=None,
+    default=None,
     sort_keys=False,
     verbose: bool = True,
     create_parent=False,
     float_precision=None,
     custom_format=True,
+    custom_format_nan_to_none=False,
+    custom_format_indent_lists=False,
     encoding="utf-8",
     overwrite=True,
     **compressor_kwargs,
@@ -238,9 +229,12 @@ def dump_json_compressed(
         allow_nan=allow_nan,
         indent=indent,
         separators=separators,
+        default=default,
         sort_keys=sort_keys,
         float_precision=float_precision,
         custom_format=custom_format,
+        custom_format_nan_to_none=custom_format_nan_to_none,
+        custom_format_indent_lists=custom_format_indent_lists,
     )
     compress_data_to_file(
         json_data,
@@ -262,9 +256,12 @@ def dumps_json(
     allow_nan=False,
     indent=None,
     separators=None,
+    default=None,
     sort_keys=False,
     float_precision=None,
     custom_format=True,
+    custom_format_indent_lists=False,
+    custom_format_nan_to_none=False,
 ) -> str:
     """Write data to json string using the custom json encoder"""
     if indent is None and separators is None:
@@ -276,6 +273,7 @@ def dumps_json(
         allow_nan=allow_nan,
         indent=indent,
         separators=separators,
+        default=default,
         sort_keys=sort_keys,
     )
     if custom_format:
@@ -283,6 +281,8 @@ def dumps_json(
             dict(
                 cls=CustomJSONEncoder,
                 float_precision=float_precision,
+                custom_format_nan_to_none=custom_format_nan_to_none,
+                custom_format_indent_lists=custom_format_indent_lists,
             )
         )
     return json.dumps(obj, **kwargs)
@@ -295,9 +295,17 @@ def dump_jsonl(
     create_parent=False,
     encoding="utf-8",
     overwrite=True,
+    ensure_ascii: bool = False,
+    check_circular: bool = False,
+    allow_nan=False,
+    separators=None,
+    default=None,
+    sort_keys=False,
+    float_precision=None,
+    custom_format=True,
+    custom_format_nan_to_none=False,
 ) -> None:
-    """Write lines of data to jsonl (list of json strings) file or file object
-    using the custom json encoder"""
+    """Write lines of data to jsonl (list of json strings) file or file object"""
     start_timer = timer()
     if not _check_can_write(file_or_io, overwrite, verbose):
         return
@@ -308,7 +316,19 @@ def dump_jsonl(
 
     with open_file_or_io(file_or_io, "wt", encoding=encoding, create_parent=create_parent) as fh:
         for d in data:
-            fh.write(f"{dumps_json(d)}\n")
+            json_line = dumps_json(
+                d,
+                ensure_ascii=ensure_ascii,
+                check_circular=check_circular,
+                allow_nan=allow_nan,
+                separators=separators,
+                default=default,
+                sort_keys=sort_keys,
+                float_precision=float_precision,
+                custom_format=custom_format,
+                custom_format_nan_to_none=custom_format_nan_to_none,
+            )
+            fh.write(f"{json_line}\n")
 
     if verbose:
         print(f"Wrote jsonl file {file_or_io} in {timer() - start_timer:.3f} seconds")
@@ -322,6 +342,15 @@ def dump_jsonl_compressed(
     create_parent=False,
     encoding="utf-8",
     overwrite=True,
+    ensure_ascii: bool = False,
+    check_circular: bool = False,
+    allow_nan=False,
+    separators=None,
+    default=None,
+    sort_keys=False,
+    float_precision=None,
+    custom_format=True,
+    custom_format_nan_to_none=False,
     **compressor_kwargs,
 ) -> None:
     """Write lines of data to jsonl (list of json strings) file or file object
@@ -331,7 +360,18 @@ def dump_jsonl_compressed(
         return
 
     try:
-        jsonl_data = dumps_jsonl(data)
+        jsonl_data = dumps_jsonl(
+            data,
+            ensure_ascii=ensure_ascii,
+            check_circular=check_circular,
+            allow_nan=allow_nan,
+            separators=separators,
+            default=default,
+            sort_keys=sort_keys,
+            float_precision=float_precision,
+            custom_format=custom_format,
+            custom_format_nan_to_none=custom_format_nan_to_none,
+        )
     except Exception as e:
         raise RuntimeError(f"Error dumping jsonl file {file_or_io}") from e
 
@@ -347,9 +387,9 @@ def dump_jsonl_compressed(
         print(f"Wrote jsonl file {file_or_io} in {timer() - start_timer:.3f} seconds")
 
 
-def dumps_jsonl(data: Iterable[Any]) -> str:
+def dumps_jsonl(data: Iterable[Any], **kwargs) -> str:
     sio = io.StringIO()
-    dump_jsonl(data, sio, verbose=False)
+    dump_jsonl(data, sio, verbose=False, **kwargs)
     return sio.getvalue()
 
 
