@@ -8,21 +8,21 @@ Other contents of this file: Utils for the standard library logging package,
 Utils for the loguru package.
 https://loguru.readthedocs.io/en/stable/resources/recipes.html#changing-the-level-of-an-existing-handler
 """
-from __future__ import annotations
 
-from logging import getLevelName
+from __future__ import annotations
 
 import itertools
 import logging
 import os
 import sys
 from copy import deepcopy
+from logging import getLevelName
+from typing import Union
+
 from deprecated import deprecated
 from loguru import logger as loguru_logger
 from pathspec import PathSpec
-from typing import Union
 
-from packg.iotools.pathspec_matcher import make_pathspec
 from typedparser import VerboseQuietArgs
 
 LevelType = Union[str, int]  # either "DEBUG" or 10
@@ -46,9 +46,9 @@ BRIGHTBG_FORMAT = (
     "<level>{message}</level>"
 )
 TIMELESS_FORMAT = "<level>{level: <4.4}</level> <level>{message}</level>"
-
 SPINNER_STR = "|/-\\"
 SPINNER_CYCLE = itertools.cycle("|/-\\")
+LOG_LEVEL_NAMES = ["CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG"]  # logging._nameToLevel
 
 
 def get_stdlib_logging_formatter():
@@ -182,9 +182,21 @@ def get_level_as_int(level: LevelType):
 
 def get_logger_level_from_args(args: VerboseQuietArgs) -> str:
     if args.verbose:
+        assert args.loglevel is None, "Cannot set both -v/--verbose and --log_level LEVEL"
         return "DEBUG"
     if args.quiet:
+        assert args.loglevel is None, "Cannot set both -q/--quiet and --log_level LEVEL"
         return "WARNING"
+    loglevel = args.loglevel
+    if loglevel == "WARN":
+        print("Deprecation: log level WARN is deprecated, use WARNING instead", file=sys.stderr)
+        loglevel = "WARNING"
+    if loglevel == "FATAL":
+        print("Deprecation: log level FATAL is deprecated, use CRITICAL instead", file=sys.stderr)
+        loglevel = "CRITICAL"
+    if loglevel is not None:
+        assert loglevel in LOG_LEVEL_NAMES, f"{loglevel=} not in {LOG_LEVEL_NAMES=}"
+        return loglevel
     return "INFO"
 
 
@@ -218,10 +230,14 @@ def silence_stdlib_loggers(
     level: LevelType = logging.ERROR,
     verbose: bool = False,
 ):
+    # the packg.log module should be usable anywhere so we cannot import other packg modules here
+    # otherwise we would cause a circular import. so we put the import here inside the function.
+    from packg.iotools.pathspec_matcher import make_pathspec
+
     spec: PathSpec = make_pathspec([search_str], regex_mode=regex_mode)
     # print([p.regex for p in spec.patterns])
     level = get_level_as_int(level)
-    for name in logging.root.manager.loggerDict.keys():
+    for name in logging.root.manager.loggerDict.keys():  # pylint: disable=no-member
         loggr = logging.getLogger(name)
         if spec.match_file(name):
             loggr.setLevel(level)
