@@ -1,3 +1,4 @@
+# pylint: disable=duplicate-code
 from __future__ import annotations
 
 import time
@@ -7,6 +8,7 @@ from multiprocessing import Process, Queue
 from statistics import mean
 from timeit import default_timer
 from typing import Optional, Any
+
 from attr import define, field
 from loguru import logger
 
@@ -29,7 +31,7 @@ class MultiProcessorProducerConsumer:
         - loop put(input_args) some tasks
         - outputs = run()  # list of length n_consumers with the return from complete()
 
-    todo
+    TODO
         Improve error handling with error queues if needed
         Improve passing dict of flags / config, instead of one bool for each config item
         Create another example in this file
