@@ -5,6 +5,10 @@ from .base64tools import (
     b64_decode_to_str,
     b64_decode_to_bytes,
     get_random_b64_string,
+    b64_decode_to_int,
+    b64_encode_from_int,
 )
 from .hasher import hash_object
 from .quote_urlparse import quote_with_urlparse, unquote_with_urlparse
+from .tabul import format_pseudo_table
+from .formatters import clean_string_for_filename, dict_to_str_comma_equals
